==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/activity/l10n/ko.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "활동",
    "An error occurred while loading activities" : "활동을 불러오는 중 오류 발생",
    "No activity yet" : "아직 활동 없음",
    "Load more activities" : "더 많은 활동 불러오기",
    "Copied!" : "복사 성공!",
    "Not supported!" : "지원하지 않음!",
    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
    "{name} (invisible)" : "{name} (숨겨짐)",
    "{name} (restricted)" : "{name} (제한됨)",
    "in {path}" : "{path}에 있음",
    "This stream will show events like additions, changes & shares" : "스트림에는 추가, 변경, 공유와 같은 이벤트가 표시됩니다",
    "There are no events for this filter" : "이 필터를 만족하는 이벤트 없음",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "Personal activity feed for %s" : "%s 님의 개인 활동 피드",
    "Your feed URL is invalid" : "피드 주소가 잘못되었습니다",
    "Your settings have been updated." : "설정이 업데이트 되었습니다.",
    "Settings have been updated." : "설정이 업데이트 되었습니다.",
    "Mail" : "메일",
    "Stream" : "스트림",
    "All activities" : "모든 활동",
    "By others" : "다른 사람",
    "By you" : "나",
    "\"remote user\"" : "\"원격 사용자\"",
    "Hello %s" : "%s 님 안녕하세요",
    "Hello %s," : "%s 님 안녕하세요,",
    "There was some activity at %s" : "%s에 새로운 활동이 있었습니다",
    "_and %n more _::_and %n more _" : ["%n개 더"],
    "Activity notification" : "활동 알림",
    ", " : ", ",
    "%s and %s" : "%s, %s",
    "Activity" : "활동",
    "Activity feed" : "활동 피드",
    "Send activity emails" : "활동 이메일을 보냄",
    "Default settings" : "기본설정",
    "Configure the default activity settings for new users." : "새 사용자의 기본 활동 설정을 변경합니다.",
    "List your own actions in the stream" : "내 활동을 스트림에 추가하기",
    "Notify about your own actions via email" : "내 활동도 이메일로 알림 받기",
    "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다.",
    "Send emails:" : "이메일 보내는 간격:",
    "As soon as possible" : "빠른 시일내에",
    "Hourly" : "1시간마다",
    "Daily" : "매일",
    "Weekly" : "매주",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "이메일 알림을 받거나 활동 앱 스트림에 표시할 활동을 선택합니다.",
    "Choose which activities you want to see in your stream." : "스트림에서 보고 싶은 활동들을 선택하세요.",
    "Settings" : "설정",
    "Enable RSS feed" : "RSS 피드 사용",
    "No more events to load" : "더 이상 불러올 이벤트 없음",
    "Files" : "파일",
    "Error loading activities" : "활동들을 로딩하는데 에러 발생",
    "No activities" : "활동 없음",
    "You are receiving this email because the following things happened at %s" : "%s에 다음과 같은 것들이 발생하여 본 이메일을 받게 된것입니다.",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* 그 외 %n개 더 있음"]
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/activity/l10n/ko.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "활동",
    "An error occurred while loading activities" : "활동을 불러오는 중 오류 발생",
    "No activity yet" : "아직 활동 없음",
    "Load more activities" : "더 많은 활동 불러오기",
    "Copied!" : "복사 성공!",
    "Not supported!" : "지원하지 않음!",
    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
    "Home" : "홈",
    "{name} (invisible)" : "{name} (숨겨짐)",
    "{name} (restricted)" : "{name} (제한됨)",
    "in {path}" : "{path}에 있음",
    "This stream will show events like additions, changes & shares" : "스트림에는 추가, 변경, 공유와 같은 이벤트가 표시됩니다",
    "There are no events for this filter" : "이 필터를 만족하는 이벤트 없음",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "Open file" : "파일 열기",
    "Personal activity feed for %s" : "%s 님의 개인 활동 피드",
    "Your feed URL is invalid" : "피드 주소가 잘못되었습니다",
    "Your settings have been updated." : "설정이 업데이트 되었습니다.",
    "Settings have been updated." : "설정이 업데이트 되었습니다.",
    "Mail" : "메일",
    "Stream" : "스트림",
    "All activities" : "모든 활동",
    "By others" : "다른 사람",
    "By you" : "나",
    "\"remote user\"" : "\"원격 사용자\"",
    "Hello %s" : "%s 님 안녕하세요",
    "Hello %s," : "%s 님 안녕하세요,",
    "There was some activity at %s" : "%s에 새로운 활동이 있었습니다",
    "_and %n more _::_and %n more _" : ["%n개 더"],
    "Activity notification" : "활동 알림",
    ", " : ", ",
    "%s and %s" : "%s, %s",
    "Activity" : "활동",
    "Activity feed" : "활동 피드",
    "Send activity emails" : "활동 이메일 보내기",
    "Default settings" : "기본 설정",
    "Configure the default activity settings for new users." : "새 사용자의 기본 활동 설정을 변경합니다.",
    "List your own actions in the stream" : "내 활동을 스트림에 추가하기",
    "Notify about your own actions via email" : "내 활동도 이메일로 알림 받기",
    "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다.",
    "Send emails:" : "이메일 보내는 간격:",
    "As soon as possible" : "빠른 시일 내에",
    "Hourly" : "1시간마다",
    "Daily" : "매일",
    "Weekly" : "매주",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "이메일 알림을 받거나 활동 앱 스트림에 표시할 활동을 선택합니다.",
    "Choose which activities you want to see in your stream." : "스트림에 표시할 활동을 선택하십시오.",
    "Settings" : "설정",
    "Enable RSS feed" : "RSS 피드 사용",
    "RSS feed" : "RSS 피드",
    "No more events to load" : "더 이상 불러올 이벤트 없음",
    "Files" : "파일",
    "Error loading activities" : "활동을 불러오는 중 오류 발생",
    "No activities" : "활동 없음",
    "You are receiving this email because the following things happened at %s" : "%s에서 다음 활동이 있었기 때문에 이 이메일을 보냈습니다",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* 그 외 %n개 더 있음"]
},
"nplurals=1; plural=0;");
